# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.usage_billable_summary_body import UsageBillableSummaryBody


class UsageBillableSummaryKeys(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.usage_billable_summary_body import UsageBillableSummaryBody

        return {
            "apm_fargate_average": (UsageBillableSummaryBody,),
            "apm_fargate_sum": (UsageBillableSummaryBody,),
            "apm_host_sum": (UsageBillableSummaryBody,),
            "apm_host_top99p": (UsageBillableSummaryBody,),
            "apm_profiler_host_sum": (UsageBillableSummaryBody,),
            "apm_profiler_host_top99p": (UsageBillableSummaryBody,),
            "apm_trace_search_sum": (UsageBillableSummaryBody,),
            "application_security_fargate_average": (UsageBillableSummaryBody,),
            "application_security_host_sum": (UsageBillableSummaryBody,),
            "application_security_host_top99": (UsageBillableSummaryBody,),
            "ci_pipeline_indexed_spans_sum": (UsageBillableSummaryBody,),
            "ci_pipeline_maximum": (UsageBillableSummaryBody,),
            "ci_pipeline_sum": (UsageBillableSummaryBody,),
            "ci_test_indexed_spans_sum": (UsageBillableSummaryBody,),
            "ci_testing_maximum": (UsageBillableSummaryBody,),
            "ci_testing_sum": (UsageBillableSummaryBody,),
            "cloud_cost_management_average": (UsageBillableSummaryBody,),
            "cloud_cost_management_sum": (UsageBillableSummaryBody,),
            "cspm_container_sum": (UsageBillableSummaryBody,),
            "cspm_host_sum": (UsageBillableSummaryBody,),
            "cspm_host_top99p": (UsageBillableSummaryBody,),
            "custom_event_sum": (UsageBillableSummaryBody,),
            "cws_container_sum": (UsageBillableSummaryBody,),
            "cws_host_sum": (UsageBillableSummaryBody,),
            "cws_host_top99p": (UsageBillableSummaryBody,),
            "dbm_host_sum": (UsageBillableSummaryBody,),
            "dbm_host_top99p": (UsageBillableSummaryBody,),
            "dbm_normalized_queries_average": (UsageBillableSummaryBody,),
            "dbm_normalized_queries_sum": (UsageBillableSummaryBody,),
            "fargate_container_apm_and_profiler_average": (UsageBillableSummaryBody,),
            "fargate_container_apm_and_profiler_sum": (UsageBillableSummaryBody,),
            "fargate_container_average": (UsageBillableSummaryBody,),
            "fargate_container_profiler_average": (UsageBillableSummaryBody,),
            "fargate_container_profiler_sum": (UsageBillableSummaryBody,),
            "fargate_container_sum": (UsageBillableSummaryBody,),
            "incident_management_maximum": (UsageBillableSummaryBody,),
            "incident_management_sum": (UsageBillableSummaryBody,),
            "infra_and_apm_host_sum": (UsageBillableSummaryBody,),
            "infra_and_apm_host_top99p": (UsageBillableSummaryBody,),
            "infra_container_sum": (UsageBillableSummaryBody,),
            "infra_host_sum": (UsageBillableSummaryBody,),
            "infra_host_top99p": (UsageBillableSummaryBody,),
            "ingested_spans_sum": (UsageBillableSummaryBody,),
            "ingested_timeseries_average": (UsageBillableSummaryBody,),
            "ingested_timeseries_sum": (UsageBillableSummaryBody,),
            "iot_sum": (UsageBillableSummaryBody,),
            "iot_top99p": (UsageBillableSummaryBody,),
            "lambda_function_average": (UsageBillableSummaryBody,),
            "lambda_function_sum": (UsageBillableSummaryBody,),
            "logs_forwarding_sum": (UsageBillableSummaryBody,),
            "logs_indexed_15day_sum": (UsageBillableSummaryBody,),
            "logs_indexed_180day_sum": (UsageBillableSummaryBody,),
            "logs_indexed_30day_sum": (UsageBillableSummaryBody,),
            "logs_indexed_360day_sum": (UsageBillableSummaryBody,),
            "logs_indexed_3day_sum": (UsageBillableSummaryBody,),
            "logs_indexed_45day_sum": (UsageBillableSummaryBody,),
            "logs_indexed_60day_sum": (UsageBillableSummaryBody,),
            "logs_indexed_7day_sum": (UsageBillableSummaryBody,),
            "logs_indexed_90day_sum": (UsageBillableSummaryBody,),
            "logs_indexed_custom_retention_sum": (UsageBillableSummaryBody,),
            "logs_indexed_sum": (UsageBillableSummaryBody,),
            "logs_ingested_sum": (UsageBillableSummaryBody,),
            "network_device_sum": (UsageBillableSummaryBody,),
            "network_device_top99p": (UsageBillableSummaryBody,),
            "npm_flow_sum": (UsageBillableSummaryBody,),
            "npm_host_sum": (UsageBillableSummaryBody,),
            "npm_host_top99p": (UsageBillableSummaryBody,),
            "observability_pipeline_sum": (UsageBillableSummaryBody,),
            "online_archive_sum": (UsageBillableSummaryBody,),
            "prof_container_sum": (UsageBillableSummaryBody,),
            "prof_host_sum": (UsageBillableSummaryBody,),
            "prof_host_top99p": (UsageBillableSummaryBody,),
            "rum_lite_sum": (UsageBillableSummaryBody,),
            "rum_replay_sum": (UsageBillableSummaryBody,),
            "rum_sum": (UsageBillableSummaryBody,),
            "rum_units_sum": (UsageBillableSummaryBody,),
            "sensitive_data_scanner_sum": (UsageBillableSummaryBody,),
            "serverless_apm_sum": (UsageBillableSummaryBody,),
            "serverless_infra_average": (UsageBillableSummaryBody,),
            "serverless_infra_sum": (UsageBillableSummaryBody,),
            "serverless_invocation_sum": (UsageBillableSummaryBody,),
            "siem_sum": (UsageBillableSummaryBody,),
            "standard_timeseries_average": (UsageBillableSummaryBody,),
            "synthetics_api_tests_sum": (UsageBillableSummaryBody,),
            "synthetics_app_testing_maximum": (UsageBillableSummaryBody,),
            "synthetics_browser_checks_sum": (UsageBillableSummaryBody,),
            "timeseries_average": (UsageBillableSummaryBody,),
            "timeseries_sum": (UsageBillableSummaryBody,),
        }

    attribute_map = {
        "apm_fargate_average": "apm_fargate_average",
        "apm_fargate_sum": "apm_fargate_sum",
        "apm_host_sum": "apm_host_sum",
        "apm_host_top99p": "apm_host_top99p",
        "apm_profiler_host_sum": "apm_profiler_host_sum",
        "apm_profiler_host_top99p": "apm_profiler_host_top99p",
        "apm_trace_search_sum": "apm_trace_search_sum",
        "application_security_fargate_average": "application_security_fargate_average",
        "application_security_host_sum": "application_security_host_sum",
        "application_security_host_top99": "application_security_host_top99",
        "ci_pipeline_indexed_spans_sum": "ci_pipeline_indexed_spans_sum",
        "ci_pipeline_maximum": "ci_pipeline_maximum",
        "ci_pipeline_sum": "ci_pipeline_sum",
        "ci_test_indexed_spans_sum": "ci_test_indexed_spans_sum",
        "ci_testing_maximum": "ci_testing_maximum",
        "ci_testing_sum": "ci_testing_sum",
        "cloud_cost_management_average": "cloud_cost_management_average",
        "cloud_cost_management_sum": "cloud_cost_management_sum",
        "cspm_container_sum": "cspm_container_sum",
        "cspm_host_sum": "cspm_host_sum",
        "cspm_host_top99p": "cspm_host_top99p",
        "custom_event_sum": "custom_event_sum",
        "cws_container_sum": "cws_container_sum",
        "cws_host_sum": "cws_host_sum",
        "cws_host_top99p": "cws_host_top99p",
        "dbm_host_sum": "dbm_host_sum",
        "dbm_host_top99p": "dbm_host_top99p",
        "dbm_normalized_queries_average": "dbm_normalized_queries_average",
        "dbm_normalized_queries_sum": "dbm_normalized_queries_sum",
        "fargate_container_apm_and_profiler_average": "fargate_container_apm_and_profiler_average",
        "fargate_container_apm_and_profiler_sum": "fargate_container_apm_and_profiler_sum",
        "fargate_container_average": "fargate_container_average",
        "fargate_container_profiler_average": "fargate_container_profiler_average",
        "fargate_container_profiler_sum": "fargate_container_profiler_sum",
        "fargate_container_sum": "fargate_container_sum",
        "incident_management_maximum": "incident_management_maximum",
        "incident_management_sum": "incident_management_sum",
        "infra_and_apm_host_sum": "infra_and_apm_host_sum",
        "infra_and_apm_host_top99p": "infra_and_apm_host_top99p",
        "infra_container_sum": "infra_container_sum",
        "infra_host_sum": "infra_host_sum",
        "infra_host_top99p": "infra_host_top99p",
        "ingested_spans_sum": "ingested_spans_sum",
        "ingested_timeseries_average": "ingested_timeseries_average",
        "ingested_timeseries_sum": "ingested_timeseries_sum",
        "iot_sum": "iot_sum",
        "iot_top99p": "iot_top99p",
        "lambda_function_average": "lambda_function_average",
        "lambda_function_sum": "lambda_function_sum",
        "logs_forwarding_sum": "logs_forwarding_sum",
        "logs_indexed_15day_sum": "logs_indexed_15day_sum",
        "logs_indexed_180day_sum": "logs_indexed_180day_sum",
        "logs_indexed_30day_sum": "logs_indexed_30day_sum",
        "logs_indexed_360day_sum": "logs_indexed_360day_sum",
        "logs_indexed_3day_sum": "logs_indexed_3day_sum",
        "logs_indexed_45day_sum": "logs_indexed_45day_sum",
        "logs_indexed_60day_sum": "logs_indexed_60day_sum",
        "logs_indexed_7day_sum": "logs_indexed_7day_sum",
        "logs_indexed_90day_sum": "logs_indexed_90day_sum",
        "logs_indexed_custom_retention_sum": "logs_indexed_custom_retention_sum",
        "logs_indexed_sum": "logs_indexed_sum",
        "logs_ingested_sum": "logs_ingested_sum",
        "network_device_sum": "network_device_sum",
        "network_device_top99p": "network_device_top99p",
        "npm_flow_sum": "npm_flow_sum",
        "npm_host_sum": "npm_host_sum",
        "npm_host_top99p": "npm_host_top99p",
        "observability_pipeline_sum": "observability_pipeline_sum",
        "online_archive_sum": "online_archive_sum",
        "prof_container_sum": "prof_container_sum",
        "prof_host_sum": "prof_host_sum",
        "prof_host_top99p": "prof_host_top99p",
        "rum_lite_sum": "rum_lite_sum",
        "rum_replay_sum": "rum_replay_sum",
        "rum_sum": "rum_sum",
        "rum_units_sum": "rum_units_sum",
        "sensitive_data_scanner_sum": "sensitive_data_scanner_sum",
        "serverless_apm_sum": "serverless_apm_sum",
        "serverless_infra_average": "serverless_infra_average",
        "serverless_infra_sum": "serverless_infra_sum",
        "serverless_invocation_sum": "serverless_invocation_sum",
        "siem_sum": "siem_sum",
        "standard_timeseries_average": "standard_timeseries_average",
        "synthetics_api_tests_sum": "synthetics_api_tests_sum",
        "synthetics_app_testing_maximum": "synthetics_app_testing_maximum",
        "synthetics_browser_checks_sum": "synthetics_browser_checks_sum",
        "timeseries_average": "timeseries_average",
        "timeseries_sum": "timeseries_sum",
    }

    def __init__(
        self_,
        apm_fargate_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        apm_fargate_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        apm_host_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        apm_host_top99p: Union[UsageBillableSummaryBody, UnsetType] = unset,
        apm_profiler_host_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        apm_profiler_host_top99p: Union[UsageBillableSummaryBody, UnsetType] = unset,
        apm_trace_search_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        application_security_fargate_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        application_security_host_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        application_security_host_top99: Union[UsageBillableSummaryBody, UnsetType] = unset,
        ci_pipeline_indexed_spans_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        ci_pipeline_maximum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        ci_pipeline_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        ci_test_indexed_spans_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        ci_testing_maximum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        ci_testing_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        cloud_cost_management_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        cloud_cost_management_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        cspm_container_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        cspm_host_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        cspm_host_top99p: Union[UsageBillableSummaryBody, UnsetType] = unset,
        custom_event_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        cws_container_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        cws_host_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        cws_host_top99p: Union[UsageBillableSummaryBody, UnsetType] = unset,
        dbm_host_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        dbm_host_top99p: Union[UsageBillableSummaryBody, UnsetType] = unset,
        dbm_normalized_queries_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        dbm_normalized_queries_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        fargate_container_apm_and_profiler_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        fargate_container_apm_and_profiler_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        fargate_container_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        fargate_container_profiler_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        fargate_container_profiler_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        fargate_container_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        incident_management_maximum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        incident_management_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        infra_and_apm_host_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        infra_and_apm_host_top99p: Union[UsageBillableSummaryBody, UnsetType] = unset,
        infra_container_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        infra_host_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        infra_host_top99p: Union[UsageBillableSummaryBody, UnsetType] = unset,
        ingested_spans_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        ingested_timeseries_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        ingested_timeseries_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        iot_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        iot_top99p: Union[UsageBillableSummaryBody, UnsetType] = unset,
        lambda_function_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        lambda_function_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_forwarding_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_indexed_15day_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_indexed_180day_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_indexed_30day_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_indexed_360day_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_indexed_3day_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_indexed_45day_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_indexed_60day_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_indexed_7day_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_indexed_90day_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_indexed_custom_retention_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_indexed_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        logs_ingested_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        network_device_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        network_device_top99p: Union[UsageBillableSummaryBody, UnsetType] = unset,
        npm_flow_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        npm_host_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        npm_host_top99p: Union[UsageBillableSummaryBody, UnsetType] = unset,
        observability_pipeline_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        online_archive_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        prof_container_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        prof_host_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        prof_host_top99p: Union[UsageBillableSummaryBody, UnsetType] = unset,
        rum_lite_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        rum_replay_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        rum_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        rum_units_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        sensitive_data_scanner_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        serverless_apm_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        serverless_infra_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        serverless_infra_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        serverless_invocation_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        siem_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        standard_timeseries_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        synthetics_api_tests_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        synthetics_app_testing_maximum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        synthetics_browser_checks_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        timeseries_average: Union[UsageBillableSummaryBody, UnsetType] = unset,
        timeseries_sum: Union[UsageBillableSummaryBody, UnsetType] = unset,
        **kwargs,
    ):
        """
        Response with aggregated usage types.

        :param apm_fargate_average: Response with properties for each aggregated usage type.
        :type apm_fargate_average: UsageBillableSummaryBody, optional

        :param apm_fargate_sum: Response with properties for each aggregated usage type.
        :type apm_fargate_sum: UsageBillableSummaryBody, optional

        :param apm_host_sum: Response with properties for each aggregated usage type.
        :type apm_host_sum: UsageBillableSummaryBody, optional

        :param apm_host_top99p: Response with properties for each aggregated usage type.
        :type apm_host_top99p: UsageBillableSummaryBody, optional

        :param apm_profiler_host_sum: Response with properties for each aggregated usage type.
        :type apm_profiler_host_sum: UsageBillableSummaryBody, optional

        :param apm_profiler_host_top99p: Response with properties for each aggregated usage type.
        :type apm_profiler_host_top99p: UsageBillableSummaryBody, optional

        :param apm_trace_search_sum: Response with properties for each aggregated usage type.
        :type apm_trace_search_sum: UsageBillableSummaryBody, optional

        :param application_security_fargate_average: Response with properties for each aggregated usage type.
        :type application_security_fargate_average: UsageBillableSummaryBody, optional

        :param application_security_host_sum: Response with properties for each aggregated usage type.
        :type application_security_host_sum: UsageBillableSummaryBody, optional

        :param application_security_host_top99: Response with properties for each aggregated usage type.
        :type application_security_host_top99: UsageBillableSummaryBody, optional

        :param ci_pipeline_indexed_spans_sum: Response with properties for each aggregated usage type.
        :type ci_pipeline_indexed_spans_sum: UsageBillableSummaryBody, optional

        :param ci_pipeline_maximum: Response with properties for each aggregated usage type.
        :type ci_pipeline_maximum: UsageBillableSummaryBody, optional

        :param ci_pipeline_sum: Response with properties for each aggregated usage type.
        :type ci_pipeline_sum: UsageBillableSummaryBody, optional

        :param ci_test_indexed_spans_sum: Response with properties for each aggregated usage type.
        :type ci_test_indexed_spans_sum: UsageBillableSummaryBody, optional

        :param ci_testing_maximum: Response with properties for each aggregated usage type.
        :type ci_testing_maximum: UsageBillableSummaryBody, optional

        :param ci_testing_sum: Response with properties for each aggregated usage type.
        :type ci_testing_sum: UsageBillableSummaryBody, optional

        :param cloud_cost_management_average: Response with properties for each aggregated usage type.
        :type cloud_cost_management_average: UsageBillableSummaryBody, optional

        :param cloud_cost_management_sum: Response with properties for each aggregated usage type.
        :type cloud_cost_management_sum: UsageBillableSummaryBody, optional

        :param cspm_container_sum: Response with properties for each aggregated usage type.
        :type cspm_container_sum: UsageBillableSummaryBody, optional

        :param cspm_host_sum: Response with properties for each aggregated usage type.
        :type cspm_host_sum: UsageBillableSummaryBody, optional

        :param cspm_host_top99p: Response with properties for each aggregated usage type.
        :type cspm_host_top99p: UsageBillableSummaryBody, optional

        :param custom_event_sum: Response with properties for each aggregated usage type.
        :type custom_event_sum: UsageBillableSummaryBody, optional

        :param cws_container_sum: Response with properties for each aggregated usage type.
        :type cws_container_sum: UsageBillableSummaryBody, optional

        :param cws_host_sum: Response with properties for each aggregated usage type.
        :type cws_host_sum: UsageBillableSummaryBody, optional

        :param cws_host_top99p: Response with properties for each aggregated usage type.
        :type cws_host_top99p: UsageBillableSummaryBody, optional

        :param dbm_host_sum: Response with properties for each aggregated usage type.
        :type dbm_host_sum: UsageBillableSummaryBody, optional

        :param dbm_host_top99p: Response with properties for each aggregated usage type.
        :type dbm_host_top99p: UsageBillableSummaryBody, optional

        :param dbm_normalized_queries_average: Response with properties for each aggregated usage type.
        :type dbm_normalized_queries_average: UsageBillableSummaryBody, optional

        :param dbm_normalized_queries_sum: Response with properties for each aggregated usage type.
        :type dbm_normalized_queries_sum: UsageBillableSummaryBody, optional

        :param fargate_container_apm_and_profiler_average: Response with properties for each aggregated usage type.
        :type fargate_container_apm_and_profiler_average: UsageBillableSummaryBody, optional

        :param fargate_container_apm_and_profiler_sum: Response with properties for each aggregated usage type.
        :type fargate_container_apm_and_profiler_sum: UsageBillableSummaryBody, optional

        :param fargate_container_average: Response with properties for each aggregated usage type.
        :type fargate_container_average: UsageBillableSummaryBody, optional

        :param fargate_container_profiler_average: Response with properties for each aggregated usage type.
        :type fargate_container_profiler_average: UsageBillableSummaryBody, optional

        :param fargate_container_profiler_sum: Response with properties for each aggregated usage type.
        :type fargate_container_profiler_sum: UsageBillableSummaryBody, optional

        :param fargate_container_sum: Response with properties for each aggregated usage type.
        :type fargate_container_sum: UsageBillableSummaryBody, optional

        :param incident_management_maximum: Response with properties for each aggregated usage type.
        :type incident_management_maximum: UsageBillableSummaryBody, optional

        :param incident_management_sum: Response with properties for each aggregated usage type.
        :type incident_management_sum: UsageBillableSummaryBody, optional

        :param infra_and_apm_host_sum: Response with properties for each aggregated usage type.
        :type infra_and_apm_host_sum: UsageBillableSummaryBody, optional

        :param infra_and_apm_host_top99p: Response with properties for each aggregated usage type.
        :type infra_and_apm_host_top99p: UsageBillableSummaryBody, optional

        :param infra_container_sum: Response with properties for each aggregated usage type.
        :type infra_container_sum: UsageBillableSummaryBody, optional

        :param infra_host_sum: Response with properties for each aggregated usage type.
        :type infra_host_sum: UsageBillableSummaryBody, optional

        :param infra_host_top99p: Response with properties for each aggregated usage type.
        :type infra_host_top99p: UsageBillableSummaryBody, optional

        :param ingested_spans_sum: Response with properties for each aggregated usage type.
        :type ingested_spans_sum: UsageBillableSummaryBody, optional

        :param ingested_timeseries_average: Response with properties for each aggregated usage type.
        :type ingested_timeseries_average: UsageBillableSummaryBody, optional

        :param ingested_timeseries_sum: Response with properties for each aggregated usage type.
        :type ingested_timeseries_sum: UsageBillableSummaryBody, optional

        :param iot_sum: Response with properties for each aggregated usage type.
        :type iot_sum: UsageBillableSummaryBody, optional

        :param iot_top99p: Response with properties for each aggregated usage type.
        :type iot_top99p: UsageBillableSummaryBody, optional

        :param lambda_function_average: Response with properties for each aggregated usage type.
        :type lambda_function_average: UsageBillableSummaryBody, optional

        :param lambda_function_sum: Response with properties for each aggregated usage type.
        :type lambda_function_sum: UsageBillableSummaryBody, optional

        :param logs_forwarding_sum: Response with properties for each aggregated usage type.
        :type logs_forwarding_sum: UsageBillableSummaryBody, optional

        :param logs_indexed_15day_sum: Response with properties for each aggregated usage type.
        :type logs_indexed_15day_sum: UsageBillableSummaryBody, optional

        :param logs_indexed_180day_sum: Response with properties for each aggregated usage type.
        :type logs_indexed_180day_sum: UsageBillableSummaryBody, optional

        :param logs_indexed_30day_sum: Response with properties for each aggregated usage type.
        :type logs_indexed_30day_sum: UsageBillableSummaryBody, optional

        :param logs_indexed_360day_sum: Response with properties for each aggregated usage type.
        :type logs_indexed_360day_sum: UsageBillableSummaryBody, optional

        :param logs_indexed_3day_sum: Response with properties for each aggregated usage type.
        :type logs_indexed_3day_sum: UsageBillableSummaryBody, optional

        :param logs_indexed_45day_sum: Response with properties for each aggregated usage type.
        :type logs_indexed_45day_sum: UsageBillableSummaryBody, optional

        :param logs_indexed_60day_sum: Response with properties for each aggregated usage type.
        :type logs_indexed_60day_sum: UsageBillableSummaryBody, optional

        :param logs_indexed_7day_sum: Response with properties for each aggregated usage type.
        :type logs_indexed_7day_sum: UsageBillableSummaryBody, optional

        :param logs_indexed_90day_sum: Response with properties for each aggregated usage type.
        :type logs_indexed_90day_sum: UsageBillableSummaryBody, optional

        :param logs_indexed_custom_retention_sum: Response with properties for each aggregated usage type.
        :type logs_indexed_custom_retention_sum: UsageBillableSummaryBody, optional

        :param logs_indexed_sum: Response with properties for each aggregated usage type.
        :type logs_indexed_sum: UsageBillableSummaryBody, optional

        :param logs_ingested_sum: Response with properties for each aggregated usage type.
        :type logs_ingested_sum: UsageBillableSummaryBody, optional

        :param network_device_sum: Response with properties for each aggregated usage type.
        :type network_device_sum: UsageBillableSummaryBody, optional

        :param network_device_top99p: Response with properties for each aggregated usage type.
        :type network_device_top99p: UsageBillableSummaryBody, optional

        :param npm_flow_sum: Response with properties for each aggregated usage type.
        :type npm_flow_sum: UsageBillableSummaryBody, optional

        :param npm_host_sum: Response with properties for each aggregated usage type.
        :type npm_host_sum: UsageBillableSummaryBody, optional

        :param npm_host_top99p: Response with properties for each aggregated usage type.
        :type npm_host_top99p: UsageBillableSummaryBody, optional

        :param observability_pipeline_sum: Response with properties for each aggregated usage type.
        :type observability_pipeline_sum: UsageBillableSummaryBody, optional

        :param online_archive_sum: Response with properties for each aggregated usage type.
        :type online_archive_sum: UsageBillableSummaryBody, optional

        :param prof_container_sum: Response with properties for each aggregated usage type.
        :type prof_container_sum: UsageBillableSummaryBody, optional

        :param prof_host_sum: Response with properties for each aggregated usage type.
        :type prof_host_sum: UsageBillableSummaryBody, optional

        :param prof_host_top99p: Response with properties for each aggregated usage type.
        :type prof_host_top99p: UsageBillableSummaryBody, optional

        :param rum_lite_sum: Response with properties for each aggregated usage type.
        :type rum_lite_sum: UsageBillableSummaryBody, optional

        :param rum_replay_sum: Response with properties for each aggregated usage type.
        :type rum_replay_sum: UsageBillableSummaryBody, optional

        :param rum_sum: Response with properties for each aggregated usage type.
        :type rum_sum: UsageBillableSummaryBody, optional

        :param rum_units_sum: Response with properties for each aggregated usage type.
        :type rum_units_sum: UsageBillableSummaryBody, optional

        :param sensitive_data_scanner_sum: Response with properties for each aggregated usage type.
        :type sensitive_data_scanner_sum: UsageBillableSummaryBody, optional

        :param serverless_apm_sum: Response with properties for each aggregated usage type.
        :type serverless_apm_sum: UsageBillableSummaryBody, optional

        :param serverless_infra_average: Response with properties for each aggregated usage type.
        :type serverless_infra_average: UsageBillableSummaryBody, optional

        :param serverless_infra_sum: Response with properties for each aggregated usage type.
        :type serverless_infra_sum: UsageBillableSummaryBody, optional

        :param serverless_invocation_sum: Response with properties for each aggregated usage type.
        :type serverless_invocation_sum: UsageBillableSummaryBody, optional

        :param siem_sum: Response with properties for each aggregated usage type.
        :type siem_sum: UsageBillableSummaryBody, optional

        :param standard_timeseries_average: Response with properties for each aggregated usage type.
        :type standard_timeseries_average: UsageBillableSummaryBody, optional

        :param synthetics_api_tests_sum: Response with properties for each aggregated usage type.
        :type synthetics_api_tests_sum: UsageBillableSummaryBody, optional

        :param synthetics_app_testing_maximum: Response with properties for each aggregated usage type.
        :type synthetics_app_testing_maximum: UsageBillableSummaryBody, optional

        :param synthetics_browser_checks_sum: Response with properties for each aggregated usage type.
        :type synthetics_browser_checks_sum: UsageBillableSummaryBody, optional

        :param timeseries_average: Response with properties for each aggregated usage type.
        :type timeseries_average: UsageBillableSummaryBody, optional

        :param timeseries_sum: Response with properties for each aggregated usage type.
        :type timeseries_sum: UsageBillableSummaryBody, optional
        """
        if apm_fargate_average is not unset:
            kwargs["apm_fargate_average"] = apm_fargate_average
        if apm_fargate_sum is not unset:
            kwargs["apm_fargate_sum"] = apm_fargate_sum
        if apm_host_sum is not unset:
            kwargs["apm_host_sum"] = apm_host_sum
        if apm_host_top99p is not unset:
            kwargs["apm_host_top99p"] = apm_host_top99p
        if apm_profiler_host_sum is not unset:
            kwargs["apm_profiler_host_sum"] = apm_profiler_host_sum
        if apm_profiler_host_top99p is not unset:
            kwargs["apm_profiler_host_top99p"] = apm_profiler_host_top99p
        if apm_trace_search_sum is not unset:
            kwargs["apm_trace_search_sum"] = apm_trace_search_sum
        if application_security_fargate_average is not unset:
            kwargs["application_security_fargate_average"] = application_security_fargate_average
        if application_security_host_sum is not unset:
            kwargs["application_security_host_sum"] = application_security_host_sum
        if application_security_host_top99 is not unset:
            kwargs["application_security_host_top99"] = application_security_host_top99
        if ci_pipeline_indexed_spans_sum is not unset:
            kwargs["ci_pipeline_indexed_spans_sum"] = ci_pipeline_indexed_spans_sum
        if ci_pipeline_maximum is not unset:
            kwargs["ci_pipeline_maximum"] = ci_pipeline_maximum
        if ci_pipeline_sum is not unset:
            kwargs["ci_pipeline_sum"] = ci_pipeline_sum
        if ci_test_indexed_spans_sum is not unset:
            kwargs["ci_test_indexed_spans_sum"] = ci_test_indexed_spans_sum
        if ci_testing_maximum is not unset:
            kwargs["ci_testing_maximum"] = ci_testing_maximum
        if ci_testing_sum is not unset:
            kwargs["ci_testing_sum"] = ci_testing_sum
        if cloud_cost_management_average is not unset:
            kwargs["cloud_cost_management_average"] = cloud_cost_management_average
        if cloud_cost_management_sum is not unset:
            kwargs["cloud_cost_management_sum"] = cloud_cost_management_sum
        if cspm_container_sum is not unset:
            kwargs["cspm_container_sum"] = cspm_container_sum
        if cspm_host_sum is not unset:
            kwargs["cspm_host_sum"] = cspm_host_sum
        if cspm_host_top99p is not unset:
            kwargs["cspm_host_top99p"] = cspm_host_top99p
        if custom_event_sum is not unset:
            kwargs["custom_event_sum"] = custom_event_sum
        if cws_container_sum is not unset:
            kwargs["cws_container_sum"] = cws_container_sum
        if cws_host_sum is not unset:
            kwargs["cws_host_sum"] = cws_host_sum
        if cws_host_top99p is not unset:
            kwargs["cws_host_top99p"] = cws_host_top99p
        if dbm_host_sum is not unset:
            kwargs["dbm_host_sum"] = dbm_host_sum
        if dbm_host_top99p is not unset:
            kwargs["dbm_host_top99p"] = dbm_host_top99p
        if dbm_normalized_queries_average is not unset:
            kwargs["dbm_normalized_queries_average"] = dbm_normalized_queries_average
        if dbm_normalized_queries_sum is not unset:
            kwargs["dbm_normalized_queries_sum"] = dbm_normalized_queries_sum
        if fargate_container_apm_and_profiler_average is not unset:
            kwargs["fargate_container_apm_and_profiler_average"] = fargate_container_apm_and_profiler_average
        if fargate_container_apm_and_profiler_sum is not unset:
            kwargs["fargate_container_apm_and_profiler_sum"] = fargate_container_apm_and_profiler_sum
        if fargate_container_average is not unset:
            kwargs["fargate_container_average"] = fargate_container_average
        if fargate_container_profiler_average is not unset:
            kwargs["fargate_container_profiler_average"] = fargate_container_profiler_average
        if fargate_container_profiler_sum is not unset:
            kwargs["fargate_container_profiler_sum"] = fargate_container_profiler_sum
        if fargate_container_sum is not unset:
            kwargs["fargate_container_sum"] = fargate_container_sum
        if incident_management_maximum is not unset:
            kwargs["incident_management_maximum"] = incident_management_maximum
        if incident_management_sum is not unset:
            kwargs["incident_management_sum"] = incident_management_sum
        if infra_and_apm_host_sum is not unset:
            kwargs["infra_and_apm_host_sum"] = infra_and_apm_host_sum
        if infra_and_apm_host_top99p is not unset:
            kwargs["infra_and_apm_host_top99p"] = infra_and_apm_host_top99p
        if infra_container_sum is not unset:
            kwargs["infra_container_sum"] = infra_container_sum
        if infra_host_sum is not unset:
            kwargs["infra_host_sum"] = infra_host_sum
        if infra_host_top99p is not unset:
            kwargs["infra_host_top99p"] = infra_host_top99p
        if ingested_spans_sum is not unset:
            kwargs["ingested_spans_sum"] = ingested_spans_sum
        if ingested_timeseries_average is not unset:
            kwargs["ingested_timeseries_average"] = ingested_timeseries_average
        if ingested_timeseries_sum is not unset:
            kwargs["ingested_timeseries_sum"] = ingested_timeseries_sum
        if iot_sum is not unset:
            kwargs["iot_sum"] = iot_sum
        if iot_top99p is not unset:
            kwargs["iot_top99p"] = iot_top99p
        if lambda_function_average is not unset:
            kwargs["lambda_function_average"] = lambda_function_average
        if lambda_function_sum is not unset:
            kwargs["lambda_function_sum"] = lambda_function_sum
        if logs_forwarding_sum is not unset:
            kwargs["logs_forwarding_sum"] = logs_forwarding_sum
        if logs_indexed_15day_sum is not unset:
            kwargs["logs_indexed_15day_sum"] = logs_indexed_15day_sum
        if logs_indexed_180day_sum is not unset:
            kwargs["logs_indexed_180day_sum"] = logs_indexed_180day_sum
        if logs_indexed_30day_sum is not unset:
            kwargs["logs_indexed_30day_sum"] = logs_indexed_30day_sum
        if logs_indexed_360day_sum is not unset:
            kwargs["logs_indexed_360day_sum"] = logs_indexed_360day_sum
        if logs_indexed_3day_sum is not unset:
            kwargs["logs_indexed_3day_sum"] = logs_indexed_3day_sum
        if logs_indexed_45day_sum is not unset:
            kwargs["logs_indexed_45day_sum"] = logs_indexed_45day_sum
        if logs_indexed_60day_sum is not unset:
            kwargs["logs_indexed_60day_sum"] = logs_indexed_60day_sum
        if logs_indexed_7day_sum is not unset:
            kwargs["logs_indexed_7day_sum"] = logs_indexed_7day_sum
        if logs_indexed_90day_sum is not unset:
            kwargs["logs_indexed_90day_sum"] = logs_indexed_90day_sum
        if logs_indexed_custom_retention_sum is not unset:
            kwargs["logs_indexed_custom_retention_sum"] = logs_indexed_custom_retention_sum
        if logs_indexed_sum is not unset:
            kwargs["logs_indexed_sum"] = logs_indexed_sum
        if logs_ingested_sum is not unset:
            kwargs["logs_ingested_sum"] = logs_ingested_sum
        if network_device_sum is not unset:
            kwargs["network_device_sum"] = network_device_sum
        if network_device_top99p is not unset:
            kwargs["network_device_top99p"] = network_device_top99p
        if npm_flow_sum is not unset:
            kwargs["npm_flow_sum"] = npm_flow_sum
        if npm_host_sum is not unset:
            kwargs["npm_host_sum"] = npm_host_sum
        if npm_host_top99p is not unset:
            kwargs["npm_host_top99p"] = npm_host_top99p
        if observability_pipeline_sum is not unset:
            kwargs["observability_pipeline_sum"] = observability_pipeline_sum
        if online_archive_sum is not unset:
            kwargs["online_archive_sum"] = online_archive_sum
        if prof_container_sum is not unset:
            kwargs["prof_container_sum"] = prof_container_sum
        if prof_host_sum is not unset:
            kwargs["prof_host_sum"] = prof_host_sum
        if prof_host_top99p is not unset:
            kwargs["prof_host_top99p"] = prof_host_top99p
        if rum_lite_sum is not unset:
            kwargs["rum_lite_sum"] = rum_lite_sum
        if rum_replay_sum is not unset:
            kwargs["rum_replay_sum"] = rum_replay_sum
        if rum_sum is not unset:
            kwargs["rum_sum"] = rum_sum
        if rum_units_sum is not unset:
            kwargs["rum_units_sum"] = rum_units_sum
        if sensitive_data_scanner_sum is not unset:
            kwargs["sensitive_data_scanner_sum"] = sensitive_data_scanner_sum
        if serverless_apm_sum is not unset:
            kwargs["serverless_apm_sum"] = serverless_apm_sum
        if serverless_infra_average is not unset:
            kwargs["serverless_infra_average"] = serverless_infra_average
        if serverless_infra_sum is not unset:
            kwargs["serverless_infra_sum"] = serverless_infra_sum
        if serverless_invocation_sum is not unset:
            kwargs["serverless_invocation_sum"] = serverless_invocation_sum
        if siem_sum is not unset:
            kwargs["siem_sum"] = siem_sum
        if standard_timeseries_average is not unset:
            kwargs["standard_timeseries_average"] = standard_timeseries_average
        if synthetics_api_tests_sum is not unset:
            kwargs["synthetics_api_tests_sum"] = synthetics_api_tests_sum
        if synthetics_app_testing_maximum is not unset:
            kwargs["synthetics_app_testing_maximum"] = synthetics_app_testing_maximum
        if synthetics_browser_checks_sum is not unset:
            kwargs["synthetics_browser_checks_sum"] = synthetics_browser_checks_sum
        if timeseries_average is not unset:
            kwargs["timeseries_average"] = timeseries_average
        if timeseries_sum is not unset:
            kwargs["timeseries_sum"] = timeseries_sum
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_event_size import WidgetEventSize
    from datadog_api_client.v1.model.widget_time import WidgetTime
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.event_stream_widget_definition_type import EventStreamWidgetDefinitionType


class EventStreamWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_event_size import WidgetEventSize
        from datadog_api_client.v1.model.widget_time import WidgetTime
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.event_stream_widget_definition_type import EventStreamWidgetDefinitionType

        return {
            "event_size": (WidgetEventSize,),
            "query": (str,),
            "tags_execution": (str,),
            "time": (WidgetTime,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (EventStreamWidgetDefinitionType,),
        }

    attribute_map = {
        "event_size": "event_size",
        "query": "query",
        "tags_execution": "tags_execution",
        "time": "time",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
    }

    def __init__(
        self_,
        query: str,
        type: EventStreamWidgetDefinitionType,
        event_size: Union[WidgetEventSize, UnsetType] = unset,
        tags_execution: Union[str, UnsetType] = unset,
        time: Union[WidgetTime, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The event stream is a widget version of the stream of events
        on the Event Stream view. Only available on FREE layout dashboards.

        :param event_size: Size to use to display an event.
        :type event_size: WidgetEventSize, optional

        :param query: Query to filter the event stream with.
        :type query: str

        :param tags_execution: The execution method for multi-value filters. Can be either and or or.
        :type tags_execution: str, optional

        :param time: Time setting for the widget.
        :type time: WidgetTime, optional

        :param title: Title of the widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: Size of the title.
        :type title_size: str, optional

        :param type: Type of the event stream widget.
        :type type: EventStreamWidgetDefinitionType
        """
        if event_size is not unset:
            kwargs["event_size"] = event_size
        if tags_execution is not unset:
            kwargs["tags_execution"] = tags_execution
        if time is not unset:
            kwargs["time"] = time
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        super().__init__(kwargs)

        self_.query = query
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetOrderBy(ModelSimple):
    """
    What to order by.

    :param value: Must be one of ["change", "name", "present", "past"].
    :type value: str
    """

    allowed_values = {
        "change",
        "name",
        "present",
        "past",
    }
    CHANGE: ClassVar["WidgetOrderBy"]
    NAME: ClassVar["WidgetOrderBy"]
    PRESENT: ClassVar["WidgetOrderBy"]
    PAST: ClassVar["WidgetOrderBy"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetOrderBy.CHANGE = WidgetOrderBy("change")
WidgetOrderBy.NAME = WidgetOrderBy("name")
WidgetOrderBy.PRESENT = WidgetOrderBy("present")
WidgetOrderBy.PAST = WidgetOrderBy("past")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.user_invitation_relationships import UserInvitationRelationships
    from datadog_api_client.v2.model.user_invitations_type import UserInvitationsType


class UserInvitationData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.user_invitation_relationships import UserInvitationRelationships
        from datadog_api_client.v2.model.user_invitations_type import UserInvitationsType

        return {
            "relationships": (UserInvitationRelationships,),
            "type": (UserInvitationsType,),
        }

    attribute_map = {
        "relationships": "relationships",
        "type": "type",
    }

    def __init__(self_, relationships: UserInvitationRelationships, type: UserInvitationsType, **kwargs):
        """
        Object to create a user invitation.

        :param relationships: Relationships data for user invitation.
        :type relationships: UserInvitationRelationships

        :param type: User invitations type.
        :type type: UserInvitationsType
        """
        super().__init__(kwargs)

        self_.relationships = relationships
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_live_span import WidgetLiveSpan


class NotebookRelativeTime(ModelNormal):
    _nullable = True

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_live_span import WidgetLiveSpan

        return {
            "live_span": (WidgetLiveSpan,),
        }

    attribute_map = {
        "live_span": "live_span",
    }

    def __init__(self_, live_span: WidgetLiveSpan, **kwargs):
        """
        Relative timeframe.

        :param live_span: The available timeframes depend on the widget you are using.
        :type live_span: WidgetLiveSpan
        """
        super().__init__(kwargs)

        self_.live_span = live_span



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class UsageAttributionValues(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "api_percentage": (float,),
            "api_usage": (float,),
            "apm_fargate_percentage": (float,),
            "apm_fargate_usage": (float,),
            "apm_host_percentage": (float,),
            "apm_host_usage": (float,),
            "appsec_fargate_percentage": (float,),
            "appsec_fargate_usage": (float,),
            "appsec_percentage": (float,),
            "appsec_usage": (float,),
            "browser_percentage": (float,),
            "browser_usage": (float,),
            "container_percentage": (float,),
            "container_usage": (float,),
            "cspm_container_percentage": (float,),
            "cspm_container_usage": (float,),
            "cspm_host_percentage": (float,),
            "cspm_host_usage": (float,),
            "custom_timeseries_percentage": (float,),
            "custom_timeseries_usage": (float,),
            "cws_container_percentage": (float,),
            "cws_container_usage": (float,),
            "cws_host_percentage": (float,),
            "cws_host_usage": (float,),
            "dbm_hosts_percentage": (float,),
            "dbm_hosts_usage": (float,),
            "dbm_queries_percentage": (float,),
            "dbm_queries_usage": (float,),
            "estimated_indexed_logs_percentage": (float,),
            "estimated_indexed_logs_usage": (float,),
            "estimated_indexed_spans_percentage": (float,),
            "estimated_indexed_spans_usage": (float,),
            "estimated_ingested_logs_percentage": (float,),
            "estimated_ingested_logs_usage": (float,),
            "estimated_ingested_spans_percentage": (float,),
            "estimated_ingested_spans_usage": (float,),
            "estimated_rum_sessions_percentage": (float,),
            "estimated_rum_sessions_usage": (float,),
            "infra_host_percentage": (float,),
            "infra_host_usage": (float,),
            "lambda_functions_percentage": (float,),
            "lambda_functions_usage": (float,),
            "lambda_invocations_percentage": (float,),
            "lambda_invocations_usage": (float,),
            "npm_host_percentage": (float,),
            "npm_host_usage": (float,),
            "profiled_container_percentage": (float,),
            "profiled_container_usage": (float,),
            "profiled_hosts_percentage": (float,),
            "profiled_hosts_usage": (float,),
            "snmp_percentage": (float,),
            "snmp_usage": (float,),
        }

    attribute_map = {
        "api_percentage": "api_percentage",
        "api_usage": "api_usage",
        "apm_fargate_percentage": "apm_fargate_percentage",
        "apm_fargate_usage": "apm_fargate_usage",
        "apm_host_percentage": "apm_host_percentage",
        "apm_host_usage": "apm_host_usage",
        "appsec_fargate_percentage": "appsec_fargate_percentage",
        "appsec_fargate_usage": "appsec_fargate_usage",
        "appsec_percentage": "appsec_percentage",
        "appsec_usage": "appsec_usage",
        "browser_percentage": "browser_percentage",
        "browser_usage": "browser_usage",
        "container_percentage": "container_percentage",
        "container_usage": "container_usage",
        "cspm_container_percentage": "cspm_container_percentage",
        "cspm_container_usage": "cspm_container_usage",
        "cspm_host_percentage": "cspm_host_percentage",
        "cspm_host_usage": "cspm_host_usage",
        "custom_timeseries_percentage": "custom_timeseries_percentage",
        "custom_timeseries_usage": "custom_timeseries_usage",
        "cws_container_percentage": "cws_container_percentage",
        "cws_container_usage": "cws_container_usage",
        "cws_host_percentage": "cws_host_percentage",
        "cws_host_usage": "cws_host_usage",
        "dbm_hosts_percentage": "dbm_hosts_percentage",
        "dbm_hosts_usage": "dbm_hosts_usage",
        "dbm_queries_percentage": "dbm_queries_percentage",
        "dbm_queries_usage": "dbm_queries_usage",
        "estimated_indexed_logs_percentage": "estimated_indexed_logs_percentage",
        "estimated_indexed_logs_usage": "estimated_indexed_logs_usage",
        "estimated_indexed_spans_percentage": "estimated_indexed_spans_percentage",
        "estimated_indexed_spans_usage": "estimated_indexed_spans_usage",
        "estimated_ingested_logs_percentage": "estimated_ingested_logs_percentage",
        "estimated_ingested_logs_usage": "estimated_ingested_logs_usage",
        "estimated_ingested_spans_percentage": "estimated_ingested_spans_percentage",
        "estimated_ingested_spans_usage": "estimated_ingested_spans_usage",
        "estimated_rum_sessions_percentage": "estimated_rum_sessions_percentage",
        "estimated_rum_sessions_usage": "estimated_rum_sessions_usage",
        "infra_host_percentage": "infra_host_percentage",
        "infra_host_usage": "infra_host_usage",
        "lambda_functions_percentage": "lambda_functions_percentage",
        "lambda_functions_usage": "lambda_functions_usage",
        "lambda_invocations_percentage": "lambda_invocations_percentage",
        "lambda_invocations_usage": "lambda_invocations_usage",
        "npm_host_percentage": "npm_host_percentage",
        "npm_host_usage": "npm_host_usage",
        "profiled_container_percentage": "profiled_container_percentage",
        "profiled_container_usage": "profiled_container_usage",
        "profiled_hosts_percentage": "profiled_hosts_percentage",
        "profiled_hosts_usage": "profiled_hosts_usage",
        "snmp_percentage": "snmp_percentage",
        "snmp_usage": "snmp_usage",
    }

    def __init__(
        self_,
        api_percentage: Union[float, UnsetType] = unset,
        api_usage: Union[float, UnsetType] = unset,
        apm_fargate_percentage: Union[float, UnsetType] = unset,
        apm_fargate_usage: Union[float, UnsetType] = unset,
        apm_host_percentage: Union[float, UnsetType] = unset,
        apm_host_usage: Union[float, UnsetType] = unset,
        appsec_fargate_percentage: Union[float, UnsetType] = unset,
        appsec_fargate_usage: Union[float, UnsetType] = unset,
        appsec_percentage: Union[float, UnsetType] = unset,
        appsec_usage: Union[float, UnsetType] = unset,
        browser_percentage: Union[float, UnsetType] = unset,
        browser_usage: Union[float, UnsetType] = unset,
        container_percentage: Union[float, UnsetType] = unset,
        container_usage: Union[float, UnsetType] = unset,
        cspm_container_percentage: Union[float, UnsetType] = unset,
        cspm_container_usage: Union[float, UnsetType] = unset,
        cspm_host_percentage: Union[float, UnsetType] = unset,
        cspm_host_usage: Union[float, UnsetType] = unset,
        custom_timeseries_percentage: Union[float, UnsetType] = unset,
        custom_timeseries_usage: Union[float, UnsetType] = unset,
        cws_container_percentage: Union[float, UnsetType] = unset,
        cws_container_usage: Union[float, UnsetType] = unset,
        cws_host_percentage: Union[float, UnsetType] = unset,
        cws_host_usage: Union[float, UnsetType] = unset,
        dbm_hosts_percentage: Union[float, UnsetType] = unset,
        dbm_hosts_usage: Union[float, UnsetType] = unset,
        dbm_queries_percentage: Union[float, UnsetType] = unset,
        dbm_queries_usage: Union[float, UnsetType] = unset,
        estimated_indexed_logs_percentage: Union[float, UnsetType] = unset,
        estimated_indexed_logs_usage: Union[float, UnsetType] = unset,
        estimated_indexed_spans_percentage: Union[float, UnsetType] = unset,
        estimated_indexed_spans_usage: Union[float, UnsetType] = unset,
        estimated_ingested_logs_percentage: Union[float, UnsetType] = unset,
        estimated_ingested_logs_usage: Union[float, UnsetType] = unset,
        estimated_ingested_spans_percentage: Union[float, UnsetType] = unset,
        estimated_ingested_spans_usage: Union[float, UnsetType] = unset,
        estimated_rum_sessions_percentage: Union[float, UnsetType] = unset,
        estimated_rum_sessions_usage: Union[float, UnsetType] = unset,
        infra_host_percentage: Union[float, UnsetType] = unset,
        infra_host_usage: Union[float, UnsetType] = unset,
        lambda_functions_percentage: Union[float, UnsetType] = unset,
        lambda_functions_usage: Union[float, UnsetType] = unset,
        lambda_invocations_percentage: Union[float, UnsetType] = unset,
        lambda_invocations_usage: Union[float, UnsetType] = unset,
        npm_host_percentage: Union[float, UnsetType] = unset,
        npm_host_usage: Union[float, UnsetType] = unset,
        profiled_container_percentage: Union[float, UnsetType] = unset,
        profiled_container_usage: Union[float, UnsetType] = unset,
        profiled_hosts_percentage: Union[float, UnsetType] = unset,
        profiled_hosts_usage: Union[float, UnsetType] = unset,
        snmp_percentage: Union[float, UnsetType] = unset,
        snmp_usage: Union[float, UnsetType] = unset,
        **kwargs,
    ):
        """
        Fields in Usage Summary by tag(s).

        :param api_percentage: The percentage of synthetic API test usage by tag(s).
        :type api_percentage: float, optional

        :param api_usage: The synthetic API test usage by tag(s).
        :type api_usage: float, optional

        :param apm_fargate_percentage: The percentage of APM ECS Fargate task usage by tag(s).
        :type apm_fargate_percentage: float, optional

        :param apm_fargate_usage: The APM ECS Fargate task usage by tag(s).
        :type apm_fargate_usage: float, optional

        :param apm_host_percentage: The percentage of APM host usage by tag(s).
        :type apm_host_percentage: float, optional

        :param apm_host_usage: The APM host usage by tag(s).
        :type apm_host_usage: float, optional

        :param appsec_fargate_percentage: The percentage of Application Security Monitoring ECS Fargate task usage by tag(s).
        :type appsec_fargate_percentage: float, optional

        :param appsec_fargate_usage: The Application Security Monitoring ECS Fargate task usage by tag(s).
        :type appsec_fargate_usage: float, optional

        :param appsec_percentage: The percentage of Application Security Monitoring host usage by tag(s).
        :type appsec_percentage: float, optional

        :param appsec_usage: The Application Security Monitoring host usage by tag(s).
        :type appsec_usage: float, optional

        :param browser_percentage: The percentage of synthetic browser test usage by tag(s).
        :type browser_percentage: float, optional

        :param browser_usage: The synthetic browser test usage by tag(s).
        :type browser_usage: float, optional

        :param container_percentage: The percentage of container usage by tag(s).
        :type container_percentage: float, optional

        :param container_usage: The container usage by tag(s).
        :type container_usage: float, optional

        :param cspm_container_percentage: The percentage of Cloud Security Posture Management container usage by tag(s)
        :type cspm_container_percentage: float, optional

        :param cspm_container_usage: The Cloud Security Posture Management container usage by tag(s)
        :type cspm_container_usage: float, optional

        :param cspm_host_percentage: The percentage of Cloud Security Posture Management host usage by tag(s)
        :type cspm_host_percentage: float, optional

        :param cspm_host_usage: The Cloud Security Posture Management host usage by tag(s)
        :type cspm_host_usage: float, optional

        :param custom_timeseries_percentage: The percentage of custom metrics usage by tag(s).
        :type custom_timeseries_percentage: float, optional

        :param custom_timeseries_usage: The custom metrics usage by tag(s).
        :type custom_timeseries_usage: float, optional

        :param cws_container_percentage: The percentage of Cloud Workload Security container usage by tag(s)
        :type cws_container_percentage: float, optional

        :param cws_container_usage: The Cloud Workload Security container usage by tag(s)
        :type cws_container_usage: float, optional

        :param cws_host_percentage: The percentage of Cloud Workload Security host usage by tag(s)
        :type cws_host_percentage: float, optional

        :param cws_host_usage: The Cloud Workload Security host usage by tag(s)
        :type cws_host_usage: float, optional

        :param dbm_hosts_percentage: The percentage of Database Monitoring host usage by tag(s).
        :type dbm_hosts_percentage: float, optional

        :param dbm_hosts_usage: The Database Monitoring host usage by tag(s).
        :type dbm_hosts_usage: float, optional

        :param dbm_queries_percentage: The percentage of Database Monitoring normalized queries usage by tag(s).
        :type dbm_queries_percentage: float, optional

        :param dbm_queries_usage: The Database Monitoring normalized queries usage by tag(s).
        :type dbm_queries_usage: float, optional

        :param estimated_indexed_logs_percentage: The percentage of estimated live indexed logs usage by tag(s). Note this field is in private beta.
        :type estimated_indexed_logs_percentage: float, optional

        :param estimated_indexed_logs_usage: The estimated live indexed logs usage by tag(s). Note this field is in private beta.
        :type estimated_indexed_logs_usage: float, optional

        :param estimated_indexed_spans_percentage: The percentage of estimated indexed spans usage by tag(s). Note this field is in private beta.
        :type estimated_indexed_spans_percentage: float, optional

        :param estimated_indexed_spans_usage: The estimated indexed spans usage by tag(s). Note this field is in private beta.
        :type estimated_indexed_spans_usage: float, optional

        :param estimated_ingested_logs_percentage: The percentage of estimated live ingested logs usage by tag(s). Note this field is in private beta.
        :type estimated_ingested_logs_percentage: float, optional

        :param estimated_ingested_logs_usage: The estimated live ingested logs usage by tag(s). Note this field is in private beta.
        :type estimated_ingested_logs_usage: float, optional

        :param estimated_ingested_spans_percentage: The percentage of estimated ingested spans usage by tag(s). Note this field is in private beta.
        :type estimated_ingested_spans_percentage: float, optional

        :param estimated_ingested_spans_usage: The estimated ingested spans usage by tag(s). Note this field is in private beta.
        :type estimated_ingested_spans_usage: float, optional

        :param estimated_rum_sessions_percentage: The percentage of estimated rum sessions usage by tag(s). This field is in private beta.
        :type estimated_rum_sessions_percentage: float, optional

        :param estimated_rum_sessions_usage: The estimated rum sessions usage by tag(s). This field is in private beta.
        :type estimated_rum_sessions_usage: float, optional

        :param infra_host_percentage: The percentage of infrastructure host usage by tag(s).
        :type infra_host_percentage: float, optional

        :param infra_host_usage: The infrastructure host usage by tag(s).
        :type infra_host_usage: float, optional

        :param lambda_functions_percentage: The percentage of Lambda function usage by tag(s).
        :type lambda_functions_percentage: float, optional

        :param lambda_functions_usage: The Lambda function usage by tag(s).
        :type lambda_functions_usage: float, optional

        :param lambda_invocations_percentage: The percentage of Lambda invocation usage by tag(s).
        :type lambda_invocations_percentage: float, optional

        :param lambda_invocations_usage: The Lambda invocation usage by tag(s).
        :type lambda_invocations_usage: float, optional

        :param npm_host_percentage: The percentage of network host usage by tag(s).
        :type npm_host_percentage: float, optional

        :param npm_host_usage: The network host usage by tag(s).
        :type npm_host_usage: float, optional

        :param profiled_container_percentage: The percentage of profiled containers usage by tag(s).
        :type profiled_container_percentage: float, optional

        :param profiled_container_usage: The profiled container usage by tag(s).
        :type profiled_container_usage: float, optional

        :param profiled_hosts_percentage: The percentage of profiled hosts usage by tag(s).
        :type profiled_hosts_percentage: float, optional

        :param profiled_hosts_usage: The profiled host usage by tag(s).
        :type profiled_hosts_usage: float, optional

        :param snmp_percentage: The percentage of network device usage by tag(s).
        :type snmp_percentage: float, optional

        :param snmp_usage: The network device usage by tag(s).
        :type snmp_usage: float, optional
        """
        if api_percentage is not unset:
            kwargs["api_percentage"] = api_percentage
        if api_usage is not unset:
            kwargs["api_usage"] = api_usage
        if apm_fargate_percentage is not unset:
            kwargs["apm_fargate_percentage"] = apm_fargate_percentage
        if apm_fargate_usage is not unset:
            kwargs["apm_fargate_usage"] = apm_fargate_usage
        if apm_host_percentage is not unset:
            kwargs["apm_host_percentage"] = apm_host_percentage
        if apm_host_usage is not unset:
            kwargs["apm_host_usage"] = apm_host_usage
        if appsec_fargate_percentage is not unset:
            kwargs["appsec_fargate_percentage"] = appsec_fargate_percentage
        if appsec_fargate_usage is not unset:
            kwargs["appsec_fargate_usage"] = appsec_fargate_usage
        if appsec_percentage is not unset:
            kwargs["appsec_percentage"] = appsec_percentage
        if appsec_usage is not unset:
            kwargs["appsec_usage"] = appsec_usage
        if browser_percentage is not unset:
            kwargs["browser_percentage"] = browser_percentage
        if browser_usage is not unset:
            kwargs["browser_usage"] = browser_usage
        if container_percentage is not unset:
            kwargs["container_percentage"] = container_percentage
        if container_usage is not unset:
            kwargs["container_usage"] = container_usage
        if cspm_container_percentage is not unset:
            kwargs["cspm_container_percentage"] = cspm_container_percentage
        if cspm_container_usage is not unset:
            kwargs["cspm_container_usage"] = cspm_container_usage
        if cspm_host_percentage is not unset:
            kwargs["cspm_host_percentage"] = cspm_host_percentage
        if cspm_host_usage is not unset:
            kwargs["cspm_host_usage"] = cspm_host_usage
        if custom_timeseries_percentage is not unset:
            kwargs["custom_timeseries_percentage"] = custom_timeseries_percentage
        if custom_timeseries_usage is not unset:
            kwargs["custom_timeseries_usage"] = custom_timeseries_usage
        if cws_container_percentage is not unset:
            kwargs["cws_container_percentage"] = cws_container_percentage
        if cws_container_usage is not unset:
            kwargs["cws_container_usage"] = cws_container_usage
        if cws_host_percentage is not unset:
            kwargs["cws_host_percentage"] = cws_host_percentage
        if cws_host_usage is not unset:
            kwargs["cws_host_usage"] = cws_host_usage
        if dbm_hosts_percentage is not unset:
            kwargs["dbm_hosts_percentage"] = dbm_hosts_percentage
        if dbm_hosts_usage is not unset:
            kwargs["dbm_hosts_usage"] = dbm_hosts_usage
        if dbm_queries_percentage is not unset:
            kwargs["dbm_queries_percentage"] = dbm_queries_percentage
        if dbm_queries_usage is not unset:
            kwargs["dbm_queries_usage"] = dbm_queries_usage
        if estimated_indexed_logs_percentage is not unset:
            kwargs["estimated_indexed_logs_percentage"] = estimated_indexed_logs_percentage
        if estimated_indexed_logs_usage is not unset:
            kwargs["estimated_indexed_logs_usage"] = estimated_indexed_logs_usage
        if estimated_indexed_spans_percentage is not unset:
            kwargs["estimated_indexed_spans_percentage"] = estimated_indexed_spans_percentage
        if estimated_indexed_spans_usage is not unset:
            kwargs["estimated_indexed_spans_usage"] = estimated_indexed_spans_usage
        if estimated_ingested_logs_percentage is not unset:
            kwargs["estimated_ingested_logs_percentage"] = estimated_ingested_logs_percentage
        if estimated_ingested_logs_usage is not unset:
            kwargs["estimated_ingested_logs_usage"] = estimated_ingested_logs_usage
        if estimated_ingested_spans_percentage is not unset:
            kwargs["estimated_ingested_spans_percentage"] = estimated_ingested_spans_percentage
        if estimated_ingested_spans_usage is not unset:
            kwargs["estimated_ingested_spans_usage"] = estimated_ingested_spans_usage
        if estimated_rum_sessions_percentage is not unset:
            kwargs["estimated_rum_sessions_percentage"] = estimated_rum_sessions_percentage
        if estimated_rum_sessions_usage is not unset:
            kwargs["estimated_rum_sessions_usage"] = estimated_rum_sessions_usage
        if infra_host_percentage is not unset:
            kwargs["infra_host_percentage"] = infra_host_percentage
        if infra_host_usage is not unset:
            kwargs["infra_host_usage"] = infra_host_usage
        if lambda_functions_percentage is not unset:
            kwargs["lambda_functions_percentage"] = lambda_functions_percentage
        if lambda_functions_usage is not unset:
            kwargs["lambda_functions_usage"] = lambda_functions_usage
        if lambda_invocations_percentage is not unset:
            kwargs["lambda_invocations_percentage"] = lambda_invocations_percentage
        if lambda_invocations_usage is not unset:
            kwargs["lambda_invocations_usage"] = lambda_invocations_usage
        if npm_host_percentage is not unset:
            kwargs["npm_host_percentage"] = npm_host_percentage
        if npm_host_usage is not unset:
            kwargs["npm_host_usage"] = npm_host_usage
        if profiled_container_percentage is not unset:
            kwargs["profiled_container_percentage"] = profiled_container_percentage
        if profiled_container_usage is not unset:
            kwargs["profiled_container_usage"] = profiled_container_usage
        if profiled_hosts_percentage is not unset:
            kwargs["profiled_hosts_percentage"] = profiled_hosts_percentage
        if profiled_hosts_usage is not unset:
            kwargs["profiled_hosts_usage"] = profiled_hosts_usage
        if snmp_percentage is not unset:
            kwargs["snmp_percentage"] = snmp_percentage
        if snmp_usage is not unset:
            kwargs["snmp_usage"] = snmp_usage
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v1.model.ip_ranges import IPRanges


class IPRangesApi:
    """
    Get a list of IP prefixes belonging to Datadog.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._get_ip_ranges_endpoint = _Endpoint(
            settings={
                "response_type": (IPRanges,),
                "auth": [],
                "endpoint_path": "/",
                "operation_id": "get_ip_ranges",
                "http_method": "GET",
                "version": "v1",
                "servers": [
                    {
                        "url": "https://{subdomain}.{site}",
                        "variables": {
                            "site": {
                                "description": "The regional site for Datadog customers.",
                                "default_value": "datadoghq.com",
                                "enum_values": [
                                    "datadoghq.com",
                                    "us3.datadoghq.com",
                                    "us5.datadoghq.com",
                                    "datadoghq.eu",
                                    "ddog-gov.com",
                                ],
                            },
                            "subdomain": {
                                "description": "The subdomain where the API is deployed.",
                                "default_value": "ip-ranges",
                            },
                        },
                    },
                    {
                        "url": "{protocol}://{name}",
                        "variables": {
                            "name": {
                                "description": "Full site DNS name.",
                                "default_value": "ip-ranges.datadoghq.com",
                            },
                            "protocol": {
                                "description": "The protocol for accessing the API.",
                                "default_value": "https",
                            },
                        },
                    },
                    {
                        "url": "https://{subdomain}.datadoghq.com",
                        "variables": {
                            "subdomain": {
                                "description": "The subdomain where the API is deployed.",
                                "default_value": "ip-ranges",
                            },
                        },
                    },
                ],
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

    def get_ip_ranges(
        self,
    ) -> IPRanges:
        """List IP Ranges.

        Get information about Datadog IP ranges.

        :rtype: IPRanges
        """
        kwargs: Dict[str, Any] = {}
        return self._get_ip_ranges_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class EventsAggregation(ModelSimple):
    """
    The type of aggregation that can be performed on events-based queries.

    :param value: If omitted defaults to "count". Must be one of ["count", "cardinality", "pc75", "pc90", "pc95", "pc98", "pc99", "sum", "min", "max", "avg"].
    :type value: str
    """

    allowed_values = {
        "count",
        "cardinality",
        "pc75",
        "pc90",
        "pc95",
        "pc98",
        "pc99",
        "sum",
        "min",
        "max",
        "avg",
    }
    COUNT: ClassVar["EventsAggregation"]
    CARDINALITY: ClassVar["EventsAggregation"]
    PC75: ClassVar["EventsAggregation"]
    PC90: ClassVar["EventsAggregation"]
    PC95: ClassVar["EventsAggregation"]
    PC98: ClassVar["EventsAggregation"]
    PC99: ClassVar["EventsAggregation"]
    SUM: ClassVar["EventsAggregation"]
    MIN: ClassVar["EventsAggregation"]
    MAX: ClassVar["EventsAggregation"]
    AVG: ClassVar["EventsAggregation"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


EventsAggregation.COUNT = EventsAggregation("count")
EventsAggregation.CARDINALITY = EventsAggregation("cardinality")
EventsAggregation.PC75 = EventsAggregation("pc75")
EventsAggregation.PC90 = EventsAggregation("pc90")
EventsAggregation.PC95 = EventsAggregation("pc95")
EventsAggregation.PC98 = EventsAggregation("pc98")
EventsAggregation.PC99 = EventsAggregation("pc99")
EventsAggregation.SUM = EventsAggregation("sum")
EventsAggregation.MIN = EventsAggregation("min")
EventsAggregation.MAX = EventsAggregation("max")
EventsAggregation.AVG = EventsAggregation("avg")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v1.model.api_key_list_response import ApiKeyListResponse
from datadog_api_client.v1.model.api_key_response import ApiKeyResponse
from datadog_api_client.v1.model.api_key import ApiKey
from datadog_api_client.v1.model.application_key_list_response import ApplicationKeyListResponse
from datadog_api_client.v1.model.application_key_response import ApplicationKeyResponse
from datadog_api_client.v1.model.application_key import ApplicationKey


class KeyManagementApi:
    """
    Manage your Datadog API and application keys. You need an API key and
    an application key for a user with the required permissions to interact
    with these endpoints. The full list of API and application keys can be
    seen on your `Datadog API page <https://app.datadoghq.com/account/settings#api>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_api_key_endpoint = _Endpoint(
            settings={
                "response_type": (ApiKeyResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/api_key",
                "operation_id": "create_api_key",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (ApiKey,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_application_key_endpoint = _Endpoint(
            settings={
                "response_type": (ApplicationKeyResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/application_key",
                "operation_id": "create_application_key",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (ApplicationKey,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_api_key_endpoint = _Endpoint(
            settings={
                "response_type": (ApiKeyResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/api_key/{key}",
                "operation_id": "delete_api_key",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "key": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "key",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._delete_application_key_endpoint = _Endpoint(
            settings={
                "response_type": (ApplicationKeyResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/application_key/{key}",
                "operation_id": "delete_application_key",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "key": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "key",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_api_key_endpoint = _Endpoint(
            settings={
                "response_type": (ApiKeyResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/api_key/{key}",
                "operation_id": "get_api_key",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "key": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "key",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_application_key_endpoint = _Endpoint(
            settings={
                "response_type": (ApplicationKeyResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/application_key/{key}",
                "operation_id": "get_application_key",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "key": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "key",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_api_keys_endpoint = _Endpoint(
            settings={
                "response_type": (ApiKeyListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/api_key",
                "operation_id": "list_api_keys",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_application_keys_endpoint = _Endpoint(
            settings={
                "response_type": (ApplicationKeyListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/application_key",
                "operation_id": "list_application_keys",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_api_key_endpoint = _Endpoint(
            settings={
                "response_type": (ApiKeyResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/api_key/{key}",
                "operation_id": "update_api_key",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "key": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "key",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (ApiKey,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_application_key_endpoint = _Endpoint(
            settings={
                "response_type": (ApplicationKeyResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/application_key/{key}",
                "operation_id": "update_application_key",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "key": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "key",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (ApplicationKey,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_api_key(
        self,
        body: ApiKey,
    ) -> ApiKeyResponse:
        """Create an API key.

        Creates an API key with a given name.

        :type body: ApiKey
        :rtype: ApiKeyResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_api_key_endpoint.call_with_http_info(**kwargs)

    def create_application_key(
        self,
        body: ApplicationKey,
    ) -> ApplicationKeyResponse:
        """Create an application key.

        Create an application key with a given name.

        :type body: ApplicationKey
        :rtype: ApplicationKeyResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_application_key_endpoint.call_with_http_info(**kwargs)

    def delete_api_key(
        self,
        key: str,
    ) -> ApiKeyResponse:
        """Delete an API key.

        Delete a given API key.

        :param key: The specific API key you are working with.
        :type key: str
        :rtype: ApiKeyResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["key"] = key

        return self._delete_api_key_endpoint.call_with_http_info(**kwargs)

    def delete_application_key(
        self,
        key: str,
    ) -> ApplicationKeyResponse:
        """Delete an application key.

        Delete a given application key.

        :param key: The specific APP key you are working with.
        :type key: str
        :rtype: ApplicationKeyResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["key"] = key

        return self._delete_application_key_endpoint.call_with_http_info(**kwargs)

    def get_api_key(
        self,
        key: str,
    ) -> ApiKeyResponse:
        """Get API key.

        Get a given API key.

        :param key: The specific API key you are working with.
        :type key: str
        :rtype: ApiKeyResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["key"] = key

        return self._get_api_key_endpoint.call_with_http_info(**kwargs)

    def get_application_key(
        self,
        key: str,
    ) -> ApplicationKeyResponse:
        """Get an application key.

        Get a given application key.

        :param key: The specific APP key you are working with.
        :type key: str
        :rtype: ApplicationKeyResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["key"] = key

        return self._get_application_key_endpoint.call_with_http_info(**kwargs)

    def list_api_keys(
        self,
    ) -> ApiKeyListResponse:
        """Get all API keys.

        Get all API keys available for your account.

        :rtype: ApiKeyListResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_api_keys_endpoint.call_with_http_info(**kwargs)

    def list_application_keys(
        self,
    ) -> ApplicationKeyListResponse:
        """Get all application keys.

        Get all application keys available for your Datadog account.

        :rtype: ApplicationKeyListResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_application_keys_endpoint.call_with_http_info(**kwargs)

    def update_api_key(
        self,
        key: str,
        body: ApiKey,
    ) -> ApiKeyResponse:
        """Edit an API key.

        Edit an API key name.

        :param key: The specific API key you are working with.
        :type key: str
        :type body: ApiKey
        :rtype: ApiKeyResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["key"] = key

        kwargs["body"] = body

        return self._update_api_key_endpoint.call_with_http_info(**kwargs)

    def update_application_key(
        self,
        key: str,
        body: ApplicationKey,
    ) -> ApplicationKeyResponse:
        """Edit an application key.

        Edit an application key name.

        :param key: The specific APP key you are working with.
        :type key: str
        :type body: ApplicationKey
        :rtype: ApplicationKeyResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["key"] = key

        kwargs["body"] = body

        return self._update_application_key_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.security_monitoring_signal_list_request_filter import (
        SecurityMonitoringSignalListRequestFilter,
    )
    from datadog_api_client.v2.model.security_monitoring_signal_list_request_page import (
        SecurityMonitoringSignalListRequestPage,
    )
    from datadog_api_client.v2.model.security_monitoring_signals_sort import SecurityMonitoringSignalsSort


class SecurityMonitoringSignalListRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.security_monitoring_signal_list_request_filter import (
            SecurityMonitoringSignalListRequestFilter,
        )
        from datadog_api_client.v2.model.security_monitoring_signal_list_request_page import (
            SecurityMonitoringSignalListRequestPage,
        )
        from datadog_api_client.v2.model.security_monitoring_signals_sort import SecurityMonitoringSignalsSort

        return {
            "filter": (SecurityMonitoringSignalListRequestFilter,),
            "page": (SecurityMonitoringSignalListRequestPage,),
            "sort": (SecurityMonitoringSignalsSort,),
        }

    attribute_map = {
        "filter": "filter",
        "page": "page",
        "sort": "sort",
    }

    def __init__(
        self_,
        filter: Union[SecurityMonitoringSignalListRequestFilter, UnsetType] = unset,
        page: Union[SecurityMonitoringSignalListRequestPage, UnsetType] = unset,
        sort: Union[SecurityMonitoringSignalsSort, UnsetType] = unset,
        **kwargs,
    ):
        """
        The request for a security signal list.

        :param filter: Search filters for listing security signals.
        :type filter: SecurityMonitoringSignalListRequestFilter, optional

        :param page: The paging attributes for listing security signals.
        :type page: SecurityMonitoringSignalListRequestPage, optional

        :param sort: The sort parameters used for querying security signals.
        :type sort: SecurityMonitoringSignalsSort, optional
        """
        if filter is not unset:
            kwargs["filter"] = filter
        if page is not unset:
            kwargs["page"] = page
        if sort is not unset:
            kwargs["sort"] = sort
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class AuthenticationValidationResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "valid": (bool,),
        }

    attribute_map = {
        "valid": "valid",
    }
    read_only_vars = {
        "valid",
    }

    def __init__(self_, valid: Union[bool, UnsetType] = unset, **kwargs):
        """
        Represent validation endpoint responses.

        :param valid: Return ``true`` if the authentication response is valid.
        :type valid: bool, optional
        """
        if valid is not unset:
            kwargs["valid"] = valid
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class MetricIngestedIndexedVolumeAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "indexed_volume": (int,),
            "ingested_volume": (int,),
        }

    attribute_map = {
        "indexed_volume": "indexed_volume",
        "ingested_volume": "ingested_volume",
    }

    def __init__(
        self_, indexed_volume: Union[int, UnsetType] = unset, ingested_volume: Union[int, UnsetType] = unset, **kwargs
    ):
        """
        Object containing the definition of a metric's ingested and indexed volume.

        :param indexed_volume: Indexed volume for the given metric.
        :type indexed_volume: int, optional

        :param ingested_volume: Ingested volume for the given metric.
        :type ingested_volume: int, optional
        """
        if indexed_volume is not unset:
            kwargs["indexed_volume"] = indexed_volume
        if ingested_volume is not unset:
            kwargs["ingested_volume"] = ingested_volume
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
    from datadog_api_client.v1.model.table_widget_has_search_bar import TableWidgetHasSearchBar
    from datadog_api_client.v1.model.table_widget_request import TableWidgetRequest
    from datadog_api_client.v1.model.widget_time import WidgetTime
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.table_widget_definition_type import TableWidgetDefinitionType


class TableWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
        from datadog_api_client.v1.model.table_widget_has_search_bar import TableWidgetHasSearchBar
        from datadog_api_client.v1.model.table_widget_request import TableWidgetRequest
        from datadog_api_client.v1.model.widget_time import WidgetTime
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.table_widget_definition_type import TableWidgetDefinitionType

        return {
            "custom_links": ([WidgetCustomLink],),
            "has_search_bar": (TableWidgetHasSearchBar,),
            "requests": ([TableWidgetRequest],),
            "time": (WidgetTime,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (TableWidgetDefinitionType,),
        }

    attribute_map = {
        "custom_links": "custom_links",
        "has_search_bar": "has_search_bar",
        "requests": "requests",
        "time": "time",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
    }

    def __init__(
        self_,
        requests: List[TableWidgetRequest],
        type: TableWidgetDefinitionType,
        custom_links: Union[List[WidgetCustomLink], UnsetType] = unset,
        has_search_bar: Union[TableWidgetHasSearchBar, UnsetType] = unset,
        time: Union[WidgetTime, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The table visualization is available on timeboards and screenboards. It displays columns of metrics grouped by tag key.

        :param custom_links: List of custom links.
        :type custom_links: [WidgetCustomLink], optional

        :param has_search_bar: Controls the display of the search bar.
        :type has_search_bar: TableWidgetHasSearchBar, optional

        :param requests: Widget definition.
        :type requests: [TableWidgetRequest]

        :param time: Time setting for the widget.
        :type time: WidgetTime, optional

        :param title: Title of your widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: Size of the title.
        :type title_size: str, optional

        :param type: Type of the table widget.
        :type type: TableWidgetDefinitionType
        """
        if custom_links is not unset:
            kwargs["custom_links"] = custom_links
        if has_search_bar is not unset:
            kwargs["has_search_bar"] = has_search_bar
        if time is not unset:
            kwargs["time"] = time
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        super().__init__(kwargs)

        self_.requests = requests
        self_.type = type



"""
Delete a private location returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.synthetics_api import SyntheticsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SyntheticsApi(api_client)
    api_instance.delete_private_location(
        location_id="location_id",
    )



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class HostTotals(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "total_active": (int,),
            "total_up": (int,),
        }

    attribute_map = {
        "total_active": "total_active",
        "total_up": "total_up",
    }

    def __init__(self_, total_active: Union[int, UnsetType] = unset, total_up: Union[int, UnsetType] = unset, **kwargs):
        """
        Total number of host currently monitored by Datadog.

        :param total_active: Total number of active host (UP and ???) reporting to Datadog.
        :type total_active: int, optional

        :param total_up: Number of host that are UP and reporting to Datadog.
        :type total_up: int, optional
        """
        if total_active is not unset:
            kwargs["total_active"] = total_active
        if total_up is not unset:
            kwargs["total_up"] = total_up
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class UsageAttributionPagination(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "limit": (int,),
            "offset": (int,),
            "sort_direction": (str,),
            "sort_name": (str,),
            "total_number_of_records": (int,),
        }

    attribute_map = {
        "limit": "limit",
        "offset": "offset",
        "sort_direction": "sort_direction",
        "sort_name": "sort_name",
        "total_number_of_records": "total_number_of_records",
    }

    def __init__(
        self_,
        limit: Union[int, UnsetType] = unset,
        offset: Union[int, UnsetType] = unset,
        sort_direction: Union[str, UnsetType] = unset,
        sort_name: Union[str, UnsetType] = unset,
        total_number_of_records: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        The metadata for the current pagination.

        :param limit: Maximum amount of records to be returned.
        :type limit: int, optional

        :param offset: Records to be skipped before beginning to return.
        :type offset: int, optional

        :param sort_direction: Direction to sort by.
        :type sort_direction: str, optional

        :param sort_name: Field to sort by.
        :type sort_name: str, optional

        :param total_number_of_records: Total number of records.
        :type total_number_of_records: int, optional
        """
        if limit is not unset:
            kwargs["limit"] = limit
        if offset is not unset:
            kwargs["offset"] = offset
        if sort_direction is not unset:
            kwargs["sort_direction"] = sort_direction
        if sort_name is not unset:
            kwargs["sort_name"] = sort_name
        if total_number_of_records is not unset:
            kwargs["total_number_of_records"] = total_number_of_records
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class UsageSDSHour(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "apm_scanned_bytes": (int,),
            "events_scanned_bytes": (int,),
            "hour": (datetime,),
            "logs_scanned_bytes": (int,),
            "org_name": (str,),
            "public_id": (str,),
            "rum_scanned_bytes": (int,),
            "total_scanned_bytes": (int,),
        }

    attribute_map = {
        "apm_scanned_bytes": "apm_scanned_bytes",
        "events_scanned_bytes": "events_scanned_bytes",
        "hour": "hour",
        "logs_scanned_bytes": "logs_scanned_bytes",
        "org_name": "org_name",
        "public_id": "public_id",
        "rum_scanned_bytes": "rum_scanned_bytes",
        "total_scanned_bytes": "total_scanned_bytes",
    }

    def __init__(
        self_,
        apm_scanned_bytes: Union[int, UnsetType] = unset,
        events_scanned_bytes: Union[int, UnsetType] = unset,
        hour: Union[datetime, UnsetType] = unset,
        logs_scanned_bytes: Union[int, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        rum_scanned_bytes: Union[int, UnsetType] = unset,
        total_scanned_bytes: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Sensitive Data Scanner usage for a given organization for a given hour.

        :param apm_scanned_bytes: The total number of bytes scanned of APM usage across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
        :type apm_scanned_bytes: int, optional

        :param events_scanned_bytes: The total number of bytes scanned of Events usage across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
        :type events_scanned_bytes: int, optional

        :param hour: The hour for the usage.
        :type hour: datetime, optional

        :param logs_scanned_bytes: The total number of bytes scanned of logs usage by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
        :type logs_scanned_bytes: int, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param rum_scanned_bytes: The total number of bytes scanned of RUM usage across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
        :type rum_scanned_bytes: int, optional

        :param total_scanned_bytes: The total number of bytes scanned across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
        :type total_scanned_bytes: int, optional
        """
        if apm_scanned_bytes is not unset:
            kwargs["apm_scanned_bytes"] = apm_scanned_bytes
        if events_scanned_bytes is not unset:
            kwargs["events_scanned_bytes"] = events_scanned_bytes
        if hour is not unset:
            kwargs["hour"] = hour
        if logs_scanned_bytes is not unset:
            kwargs["logs_scanned_bytes"] = logs_scanned_bytes
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if rum_scanned_bytes is not unset:
            kwargs["rum_scanned_bytes"] = rum_scanned_bytes
        if total_scanned_bytes is not unset:
            kwargs["total_scanned_bytes"] = total_scanned_bytes
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    none_type,
    unset,
    UnsetType,
)


class UsageRumSessionsHour(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "hour": (datetime,),
            "org_name": (str,),
            "public_id": (str,),
            "replay_session_count": (int,),
            "session_count": (int, none_type),
            "session_count_android": (int, none_type),
            "session_count_ios": (int, none_type),
            "session_count_reactnative": (int, none_type),
        }

    attribute_map = {
        "hour": "hour",
        "org_name": "org_name",
        "public_id": "public_id",
        "replay_session_count": "replay_session_count",
        "session_count": "session_count",
        "session_count_android": "session_count_android",
        "session_count_ios": "session_count_ios",
        "session_count_reactnative": "session_count_reactnative",
    }

    def __init__(
        self_,
        hour: Union[datetime, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        replay_session_count: Union[int, UnsetType] = unset,
        session_count: Union[int, none_type, UnsetType] = unset,
        session_count_android: Union[int, none_type, UnsetType] = unset,
        session_count_ios: Union[int, none_type, UnsetType] = unset,
        session_count_reactnative: Union[int, none_type, UnsetType] = unset,
        **kwargs,
    ):
        """
        Number of RUM Sessions recorded for each hour for a given organization.

        :param hour: The hour for the usage.
        :type hour: datetime, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param replay_session_count: Contains the number of RUM Replay Sessions (data available beginning November 1, 2021).
        :type replay_session_count: int, optional

        :param session_count: Contains the number of browser RUM Lite Sessions.
        :type session_count: int, none_type, optional

        :param session_count_android: Contains the number of mobile RUM Sessions on Android (data available beginning December 1, 2020).
        :type session_count_android: int, none_type, optional

        :param session_count_ios: Contains the number of mobile RUM Sessions on iOS (data available beginning December 1, 2020).
        :type session_count_ios: int, none_type, optional

        :param session_count_reactnative: Contains the number of mobile RUM Sessions on React Native (data available beginning May 1, 2022).
        :type session_count_reactnative: int, none_type, optional
        """
        if hour is not unset:
            kwargs["hour"] = hour
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if replay_session_count is not unset:
            kwargs["replay_session_count"] = replay_session_count
        if session_count is not unset:
            kwargs["session_count"] = session_count
        if session_count_android is not unset:
            kwargs["session_count_android"] = session_count_android
        if session_count_ios is not unset:
            kwargs["session_count_ios"] = session_count_ios
        if session_count_reactnative is not unset:
            kwargs["session_count_reactnative"] = session_count_reactnative
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v2.model.dashboard_list_delete_items_response import DashboardListDeleteItemsResponse
from datadog_api_client.v2.model.dashboard_list_delete_items_request import DashboardListDeleteItemsRequest
from datadog_api_client.v2.model.dashboard_list_items import DashboardListItems
from datadog_api_client.v2.model.dashboard_list_add_items_response import DashboardListAddItemsResponse
from datadog_api_client.v2.model.dashboard_list_add_items_request import DashboardListAddItemsRequest
from datadog_api_client.v2.model.dashboard_list_update_items_response import DashboardListUpdateItemsResponse
from datadog_api_client.v2.model.dashboard_list_update_items_request import DashboardListUpdateItemsRequest


class DashboardListsApi:
    """
    Interact with your dashboard lists through the API to
    organize, find, and share all of your dashboards with your team and
    organization.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_dashboard_list_items_endpoint = _Endpoint(
            settings={
                "response_type": (DashboardListAddItemsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/dashboard/lists/manual/{dashboard_list_id}/dashboards",
                "operation_id": "create_dashboard_list_items",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "dashboard_list_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "dashboard_list_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (DashboardListAddItemsRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_dashboard_list_items_endpoint = _Endpoint(
            settings={
                "response_type": (DashboardListDeleteItemsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/dashboard/lists/manual/{dashboard_list_id}/dashboards",
                "operation_id": "delete_dashboard_list_items",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "dashboard_list_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "dashboard_list_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (DashboardListDeleteItemsRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._get_dashboard_list_items_endpoint = _Endpoint(
            settings={
                "response_type": (DashboardListItems,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/dashboard/lists/manual/{dashboard_list_id}/dashboards",
                "operation_id": "get_dashboard_list_items",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "dashboard_list_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "dashboard_list_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_dashboard_list_items_endpoint = _Endpoint(
            settings={
                "response_type": (DashboardListUpdateItemsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/dashboard/lists/manual/{dashboard_list_id}/dashboards",
                "operation_id": "update_dashboard_list_items",
                "http_method": "PUT",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "dashboard_list_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "dashboard_list_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (DashboardListUpdateItemsRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_dashboard_list_items(
        self,
        dashboard_list_id: int,
        body: DashboardListAddItemsRequest,
    ) -> DashboardListAddItemsResponse:
        """Add Items to a Dashboard List.

        Add dashboards to an existing dashboard list.

        :param dashboard_list_id: ID of the dashboard list to add items to.
        :type dashboard_list_id: int
        :param body: Dashboards to add to the dashboard list.
        :type body: DashboardListAddItemsRequest
        :rtype: DashboardListAddItemsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["dashboard_list_id"] = dashboard_list_id

        kwargs["body"] = body

        return self._create_dashboard_list_items_endpoint.call_with_http_info(**kwargs)

    def delete_dashboard_list_items(
        self,
        dashboard_list_id: int,
        body: DashboardListDeleteItemsRequest,
    ) -> DashboardListDeleteItemsResponse:
        """Delete items from a dashboard list.

        Delete dashboards from an existing dashboard list.

        :param dashboard_list_id: ID of the dashboard list to delete items from.
        :type dashboard_list_id: int
        :param body: Dashboards to delete from the dashboard list.
        :type body: DashboardListDeleteItemsRequest
        :rtype: DashboardListDeleteItemsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["dashboard_list_id"] = dashboard_list_id

        kwargs["body"] = body

        return self._delete_dashboard_list_items_endpoint.call_with_http_info(**kwargs)

    def get_dashboard_list_items(
        self,
        dashboard_list_id: int,
    ) -> DashboardListItems:
        """Get items of a Dashboard List.

        Fetch the dashboard list’s dashboard definitions.

        :param dashboard_list_id: ID of the dashboard list to get items from.
        :type dashboard_list_id: int
        :rtype: DashboardListItems
        """
        kwargs: Dict[str, Any] = {}
        kwargs["dashboard_list_id"] = dashboard_list_id

        return self._get_dashboard_list_items_endpoint.call_with_http_info(**kwargs)

    def update_dashboard_list_items(
        self,
        dashboard_list_id: int,
        body: DashboardListUpdateItemsRequest,
    ) -> DashboardListUpdateItemsResponse:
        """Update items of a dashboard list.

        Update dashboards of an existing dashboard list.

        :param dashboard_list_id: ID of the dashboard list to update items from.
        :type dashboard_list_id: int
        :param body: New dashboards of the dashboard list.
        :type body: DashboardListUpdateItemsRequest
        :rtype: DashboardListUpdateItemsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["dashboard_list_id"] = dashboard_list_id

        kwargs["body"] = body

        return self._update_dashboard_list_items_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_trace_remapper_type import LogsTraceRemapperType


class LogsTraceRemapper(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_trace_remapper_type import LogsTraceRemapperType

        return {
            "is_enabled": (bool,),
            "name": (str,),
            "sources": ([str],),
            "type": (LogsTraceRemapperType,),
        }

    attribute_map = {
        "is_enabled": "is_enabled",
        "name": "name",
        "sources": "sources",
        "type": "type",
    }

    def __init__(
        self_,
        type: LogsTraceRemapperType,
        is_enabled: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        sources: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        There are two ways to improve correlation between application traces and logs.

        #.
           Follow the documentation on `how to inject a trace ID in the application logs <https://docs.datadoghq.com/tracing/connect_logs_and_traces>`_
           and by default log integrations take care of all the rest of the setup.

        #.
           Use the Trace remapper processor to define a log attribute as its associated trace ID.

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param name: Name of the processor.
        :type name: str, optional

        :param sources: Array of source attributes.
        :type sources: [str], optional

        :param type: Type of logs trace remapper.
        :type type: LogsTraceRemapperType
        """
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if name is not unset:
            kwargs["name"] = name
        if sources is not unset:
            kwargs["sources"] = sources
        super().__init__(kwargs)

        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_lookup_processor_type import LogsLookupProcessorType


class ReferenceTableLogsLookupProcessor(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_lookup_processor_type import LogsLookupProcessorType

        return {
            "is_enabled": (bool,),
            "lookup_enrichment_table": (str,),
            "name": (str,),
            "source": (str,),
            "target": (str,),
            "type": (LogsLookupProcessorType,),
        }

    attribute_map = {
        "is_enabled": "is_enabled",
        "lookup_enrichment_table": "lookup_enrichment_table",
        "name": "name",
        "source": "source",
        "target": "target",
        "type": "type",
    }

    def __init__(
        self_,
        lookup_enrichment_table: str,
        source: str,
        target: str,
        type: LogsLookupProcessorType,
        is_enabled: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        **Note** : Reference Tables are in public beta.
        Use the Lookup Processor to define a mapping between a log attribute
        and a human readable value saved in a Reference Table.
        For example, you can use the Lookup Processor to map an internal service ID
        into a human readable service name. Alternatively, you could also use it to check
        if the MAC address that just attempted to connect to the production
        environment belongs to your list of stolen machines.

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param lookup_enrichment_table: Name of the Reference Table for the source attribute and their associated target attribute values.
        :type lookup_enrichment_table: str

        :param name: Name of the processor.
        :type name: str, optional

        :param source: Source attribute used to perform the lookup.
        :type source: str

        :param target: Name of the attribute that contains the corresponding value in the mapping list.
        :type target: str

        :param type: Type of logs lookup processor.
        :type type: LogsLookupProcessorType
        """
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)

        self_.lookup_enrichment_table = lookup_enrichment_table
        self_.source = source
        self_.target = target
        self_.type = type



"""
Create a new service object returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.pager_duty_integration_api import PagerDutyIntegrationApi
from datadog_api_client.v1.model.pager_duty_service import PagerDutyService

body = PagerDutyService(
    service_key="",
    service_name="",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = PagerDutyIntegrationApi(api_client)
    response = api_instance.create_pager_duty_integration_service(body=body)

    print(response)
